==> zhongyan-manage-service-api-3.0.45-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/travel/TravelTaskDTO.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.travel;

import lombok.Data;


import java.io.Serializable;
import java.util.List;

/**
 * @author duiba
 */
@Data
public class TravelTaskDTO  implements Serializable {
    private static final long serialVersionUID = -7457237754145563372L;


    List<TravelTaskReportDTO> taskReportDetailVoList;

    /**
     * T-1 阅读Uv
     */
    private Integer preReadUv;
    /**
     * T-1 阅读Pv
     */
    private Integer preReadPv;
    /**
     * T-1 玩游戏任务
     */
    private Long preGameCount;
    /**
     * T-1游戏访问首页pv
     */
    private Integer preGameIndexPv;
    /**
     * T-1 游戏访问首页uv
     */
    private Integer preGameIndexUv;
    /**
     * T-1游戏参与pv
     */
    private Integer preGameJoinPv;
    /**
     * T-1 游戏参与uv
     */
    private Integer preGameJoinUv;

    /**
     * T-1邀请pv
     */
    private Integer preInvitePv;
    /**
     * T-1邀请uv
     */
    private Integer preInviteUv;
    /**
     * T-1 邀请一个人任务
     */
    private Integer preInviteOneCount;
    /**
     * T-1邀请俩个人任务
     */
    private Integer preInviteTwoCount;

    /**
     * T-1分享pv
     */
    private Integer preSharePv;
    /**
     * T-1分享uv
     */
    private Integer preShareUv;

    /**
     * T-1扫码uv
     */
    private Long preScanningUv;

    /**
     * T-1 助力pv
     */
    private Integer preDoAssistPv;

    /**
     * T-1助力uv
     */
    private Integer preDoAssistUv;

    /**
     * T-1人均邀请成功数
     */
    private String preDoAssistCount;

    /**
     * T-1 助力率
     */
    private String preDoAssistRate;
    /**
     * T-1邀请新关注用户数
     */
    private Long preNewUserCount;

    /**
     * T-1完成累计签到的uv
     */
    private Integer preGeneratePictureUv;

    /**
     * T-1回关人数
     */

    private Long preBackOffCount;

    /**
     * 截止当前 阅读Uv
     */
    private Integer nowReadUv;
    /**
     * 截止当前 阅读Pv
     */
    private Integer nowReadPv;
    /**
     * 截止当前玩游戏任务
     */
    private Long nowGameCount;
    /**
     * 截止当前游戏访问首页pv
     */
    private Integer nowGameIndexPv;
    /**
     * 截止当前游戏访问首页uv
     */
    private Integer nowGameIndexUv;
    /**
     * 截止当前游戏参与pv
     */
    private Integer nowGameJoinPv;
    /**
     * 截止当前 游戏参与uv
     */
    private Integer nowGameJoinUv;

    /**
     * 截止当前邀请pv
     */
    private Integer nowInvitePv;
    /**
     * 截止当前邀请uv
     */
    private Integer nowInviteUv;
    /**
     * 截止当前邀请一个人任务
     */
    private Integer nowInviteOneCount;
    /**
     * 截止当前邀请俩个人任务
     */
    private Integer nowInviteTwoCount;

    /**
     * 截止当前 分享pv
     */
    private Integer nowSharePv;
    /**
     * 截止当前分享uv
     */
    private Integer nowShareUv;

    /**
     * 截止当前扫码uv
     */
    private Long nowScanningUv;

    /**
     * 截止当前助力pv
     */
    private Integer nowDoAssistPv;

    /**
     * 截止当前助力uv
     */
    private Integer nowDoAssistUv;

    /**
     * 截止当前人均邀请成功数
     */
    private String nowDoAssistCount;

    /**
     * 截止当前助力率
     */
    private String nowDoAssistRate;
    /**
     * 截止当前邀请新关注用户数
     */
    private Long nowNewUserCount;

    /**
     * 截止当前
     */

    private Long nowBackOffCount;

    /**
     * 截止当前完成累计签到的uv
     */
    private Integer nowGeneratePictureUv;


}

==> zhongyan-manage-service-api-3.0.51-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/travel/TravelTaskDTO.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.travel;

import lombok.Data;


import java.io.Serializable;
import java.util.List;

/**
 * @author duiba
 */
@Data
public class TravelTaskDTO  implements Serializable {
    private static final long serialVersionUID = -7457237754145563372L;


    List<TravelTaskReportDTO> taskReportDetailVoList;

    /**
     * T-1 阅读Uv
     */
    private Integer preReadUv;
    /**
     * T-1 阅读Pv
     */
    private Integer preReadPv;
    /**
     * T-1 玩游戏任务
     */
    private Long preGameCount;
    /**
     * T-1游戏访问首页pv
     */
    private Integer preGameIndexPv;
    /**
     * T-1 游戏访问首页uv
     */
    private Integer preGameIndexUv;
    /**
     * T-1游戏参与pv
     */
    private Integer preGameJoinPv;
    /**
     * T-1 游戏参与uv
     */
    private Integer preGameJoinUv;

    /**
     * T-1邀请pv
     */
    private Integer preInvitePv;
    /**
     * T-1邀请uv
     */
    private Integer preInviteUv;
    /**
     * T-1 邀请一个人任务
     */
    private Integer preInviteOneCount;
    /**
     * T-1邀请俩个人任务
     */
    private Integer preInviteTwoCount;

    /**
     * T-1分享pv
     */
    private Integer preSharePv;
    /**
     * T-1分享uv
     */
    private Integer preShareUv;

    /**
     * T-1扫码uv
     */
    private Long preScanningUv;

    /**
     * T-1 助力pv
     */
    private Integer preDoAssistPv;

    /**
     * T-1助力uv
     */
    private Integer preDoAssistUv;

    /**
     * T-1人均邀请成功数
     */
    private String preDoAssistCount;

    /**
     * T-1 助力率
     */
    private String preDoAssistRate;
    /**
     * T-1邀请新关注用户数
     */
    private Long preNewUserCount;

    /**
     * T-1完成累计签到的uv
     */
    private Integer preGeneratePictureUv;

    private Integer preSignPv;

    private Integer preSignUv;

    private Integer preAnswerPv;

    private Integer preAnswerUv;

    private Integer preAnswerFailedPv;

    /**
     * T-1回关人数
     */

    private Long preBackOffCount;

    /**
     * 截止当前 阅读Uv
     */
    private Integer nowReadUv;
    /**
     * 截止当前 阅读Pv
     */
    private Integer nowReadPv;
    /**
     * 截止当前玩游戏任务
     */
    private Long nowGameCount;
    /**
     * 截止当前游戏访问首页pv
     */
    private Integer nowGameIndexPv;
    /**
     * 截止当前游戏访问首页uv
     */
    private Integer nowGameIndexUv;
    /**
     * 截止当前游戏参与pv
     */
    private Integer nowGameJoinPv;
    /**
     * 截止当前 游戏参与uv
     */
    private Integer nowGameJoinUv;

    /**
     * 截止当前邀请pv
     */
    private Integer nowInvitePv;
    /**
     * 截止当前邀请uv
     */
    private Integer nowInviteUv;
    /**
     * 截止当前邀请一个人任务
     */
    private Integer nowInviteOneCount;
    /**
     * 截止当前邀请俩个人任务
     */
    private Integer nowInviteTwoCount;

    /**
     * 截止当前 分享pv
     */
    private Integer nowSharePv;
    /**
     * 截止当前分享uv
     */
    private Integer nowShareUv;

    /**
     * 截止当前扫码uv
     */
    private Long nowScanningUv;

    /**
     * 截止当前助力pv
     */
    private Integer nowDoAssistPv;

    /**
     * 截止当前助力uv
     */
    private Integer nowDoAssistUv;

    /**
     * 截止当前人均邀请成功数
     */
    private String nowDoAssistCount;

    /**
     * 截止当前助力率
     */
    private String nowDoAssistRate;
    /**
     * 截止当前邀请新关注用户数
     */
    private Long nowNewUserCount;

    /**
     * 截止当前
     */

    private Long nowBackOffCount;

    /**
     * 截止当前完成累计签到的uv
     */
    private Integer nowGeneratePictureUv;

    private Integer nowSignPv;

    private Integer nowSignUv;

    private Integer nowAnswerPv;

    private Integer nowAnswerUv;

    private Integer nowAnswerFailedPv;

}
